@@ -40,8 +40,12 @@ if ($rep) {
 	$useMime = false;
 
 	// If there's no revision info, go to the lastest revision for this path
-	$history = $svnrep->getLog($path, 'HEAD', 1, false, 2, $peg);
-	$youngest = ($history && isset($history->entries[0])) ? $history->entries[0]->rev: false;
+	$history = $svnrep->getLog($path, 'HEAD', 1, false, 2, ($path == '/') ? '' : $peg);
+	if (!$history) {
+		unset($vars['error']);
+		$history = $svnrep->getLog($path, '', '', false, 2, ($path == '/') ? '' : $peg);
+	}
+	$youngest = ($history && isset($history->entries[0])) ? $history->entries[0]->rev : false;
 
 	if (empty($rev)) {
 		$rev = $youngest;
@@ -115,16 +119,17 @@ if ($rep) {
 	$vars['action'] = '';
 	$vars['path'] = escape($ppath);
 
-	if ($history) {
+	if (isset($history->entries[0])) {
 		$vars['log'] = xml_entities($history->entries[0]->msg);
 		$vars['date'] = $history->entries[0]->date;
+		$vars['age'] = datetimeFormatDuration(time() - strtotime($history->entries[0]->date));
 		$vars['author'] = $history->entries[0]->author;
 	}
 	createPathLinks($rep, $ppath, $passrev, $peg);
-	$passRevString = createRevAndPegString($passrev, $peg);
+	$passRevString = createRevAndPegString($rev, $peg);
 
 	if ($rev != $youngest) {
-		$vars['goyoungesturl'] = $config->getURL($rep, $path, 'file').($peg ? 'peg='.$peg : '');
+		$vars['goyoungesturl'] = $config->getURL($rep, $path, 'file').createRevAndPegString('', $peg);
 		$vars['goyoungestlink'] = '<a href="'.$vars['goyoungesturl'].'"'.($youngest ? ' title="'.$lang['REV'].' '.$youngest.'"' : '').'>'.$lang['GOYOUNGEST'].'</a>';
 	}
 
@@ -170,7 +175,7 @@ if ($rep) {
 	}
 
 	if ($rep->isRssEnabled()) {
-		$vars['rssurl'] = $config->getURL($rep, $path, 'rss').($peg ? 'peg='.$peg : '');
+		$vars['rssurl'] = $config->getURL($rep, $path, 'rss').createRevAndPegString('', $peg);
 		$vars['rsslink'] = '<a href="'.$vars['rssurl'].'">'.$lang['RSSFEED'].'</a>';
 	}
 
@@ -187,6 +192,8 @@ if ($rep) {
 	if (!$rep->hasReadAccess($path, true)) {
 		$vars['error'] = $lang['NOACCESS'];
 		checkSendingAuthHeader($rep);
+	} else if (!$svnrep->isFile($path, $rev, $peg)) {
+		$vars['error'] = $lang['NOPATH'];
 	}
 
 } else {
@@ -195,7 +202,4 @@ if ($rep) {
 
 // $listing is populated with file data when file.tmpl calls [websvn-getlisting]
 
-$vars['template'] = 'file';
-parseTemplate('header.tmpl');
-parseTemplate('file.tmpl');
-parseTemplate('footer.tmpl');
+renderTemplate('file');
